# flake8: noqa

"""
    ORY Oathkeeper

    ORY Oathkeeper is a reverse proxy that checks the HTTP Authorization for validity against a set of rules. This service uses Hydra to validate access tokens and policies.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.49
    Contact: hi@ory.am
    Generated by: https://openapi-generator.tech
"""


__version__ = "v0.0.0-alpha.49"

# import ApiClient
from ory_oathkeeper_client.api_client import ApiClient

# import Configuration
from ory_oathkeeper_client.configuration import Configuration

# import exceptions
from ory_oathkeeper_client.exceptions import OpenApiException
from ory_oathkeeper_client.exceptions import ApiAttributeError
from ory_oathkeeper_client.exceptions import ApiTypeError
from ory_oathkeeper_client.exceptions import ApiValueError
from ory_oathkeeper_client.exceptions import ApiKeyError
from ory_oathkeeper_client.exceptions import ApiException



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from ory_oathkeeper_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from ory_oathkeeper_client.model.create_rule_created import CreateRuleCreated
from ory_oathkeeper_client.model.create_rule_forbidden import CreateRuleForbidden
from ory_oathkeeper_client.model.create_rule_forbidden_body import CreateRuleForbiddenBody
from ory_oathkeeper_client.model.create_rule_internal_server_error import CreateRuleInternalServerError
from ory_oathkeeper_client.model.create_rule_internal_server_error_body import CreateRuleInternalServerErrorBody
from ory_oathkeeper_client.model.create_rule_unauthorized import CreateRuleUnauthorized
from ory_oathkeeper_client.model.create_rule_unauthorized_body import CreateRuleUnauthorizedBody
from ory_oathkeeper_client.model.decisions_forbidden import DecisionsForbidden
from ory_oathkeeper_client.model.decisions_forbidden_body import DecisionsForbiddenBody
from ory_oathkeeper_client.model.decisions_internal_server_error import DecisionsInternalServerError
from ory_oathkeeper_client.model.decisions_internal_server_error_body import DecisionsInternalServerErrorBody
from ory_oathkeeper_client.model.decisions_not_found import DecisionsNotFound
from ory_oathkeeper_client.model.decisions_not_found_body import DecisionsNotFoundBody
from ory_oathkeeper_client.model.decisions_unauthorized import DecisionsUnauthorized
from ory_oathkeeper_client.model.decisions_unauthorized_body import DecisionsUnauthorizedBody
from ory_oathkeeper_client.model.delete_rule_forbidden import DeleteRuleForbidden
from ory_oathkeeper_client.model.delete_rule_forbidden_body import DeleteRuleForbiddenBody
from ory_oathkeeper_client.model.delete_rule_internal_server_error import DeleteRuleInternalServerError
from ory_oathkeeper_client.model.delete_rule_internal_server_error_body import DeleteRuleInternalServerErrorBody
from ory_oathkeeper_client.model.delete_rule_not_found import DeleteRuleNotFound
from ory_oathkeeper_client.model.delete_rule_not_found_body import DeleteRuleNotFoundBody
from ory_oathkeeper_client.model.delete_rule_unauthorized import DeleteRuleUnauthorized
from ory_oathkeeper_client.model.delete_rule_unauthorized_body import DeleteRuleUnauthorizedBody
from ory_oathkeeper_client.model.get_rule_forbidden import GetRuleForbidden
from ory_oathkeeper_client.model.get_rule_forbidden_body import GetRuleForbiddenBody
from ory_oathkeeper_client.model.get_rule_internal_server_error import GetRuleInternalServerError
from ory_oathkeeper_client.model.get_rule_internal_server_error_body import GetRuleInternalServerErrorBody
from ory_oathkeeper_client.model.get_rule_not_found import GetRuleNotFound
from ory_oathkeeper_client.model.get_rule_not_found_body import GetRuleNotFoundBody
from ory_oathkeeper_client.model.get_rule_ok import GetRuleOK
from ory_oathkeeper_client.model.get_rule_unauthorized import GetRuleUnauthorized
from ory_oathkeeper_client.model.get_rule_unauthorized_body import GetRuleUnauthorizedBody
from ory_oathkeeper_client.model.get_well_known_forbidden import GetWellKnownForbidden
from ory_oathkeeper_client.model.get_well_known_forbidden_body import GetWellKnownForbiddenBody
from ory_oathkeeper_client.model.get_well_known_json_web_keys_internal_server_error import GetWellKnownJSONWebKeysInternalServerError
from ory_oathkeeper_client.model.get_well_known_json_web_keys_internal_server_error_body import GetWellKnownJSONWebKeysInternalServerErrorBody
from ory_oathkeeper_client.model.get_well_known_json_web_keys_ok import GetWellKnownJSONWebKeysOK
from ory_oathkeeper_client.model.get_well_known_ok import GetWellKnownOK
from ory_oathkeeper_client.model.get_well_known_unauthorized import GetWellKnownUnauthorized
from ory_oathkeeper_client.model.get_well_known_unauthorized_body import GetWellKnownUnauthorizedBody
from ory_oathkeeper_client.model.health_not_ready_status import HealthNotReadyStatus
from ory_oathkeeper_client.model.health_status import HealthStatus
from ory_oathkeeper_client.model.inline_response500 import InlineResponse500
from ory_oathkeeper_client.model.is_instance_alive_internal_server_error import IsInstanceAliveInternalServerError
from ory_oathkeeper_client.model.is_instance_alive_internal_server_error_body import IsInstanceAliveInternalServerErrorBody
from ory_oathkeeper_client.model.is_instance_alive_ok import IsInstanceAliveOK
from ory_oathkeeper_client.model.json_web_key import JsonWebKey
from ory_oathkeeper_client.model.json_web_key_set import JsonWebKeySet
from ory_oathkeeper_client.model.judge_forbidden import JudgeForbidden
from ory_oathkeeper_client.model.judge_forbidden_body import JudgeForbiddenBody
from ory_oathkeeper_client.model.judge_internal_server_error import JudgeInternalServerError
from ory_oathkeeper_client.model.judge_internal_server_error_body import JudgeInternalServerErrorBody
from ory_oathkeeper_client.model.judge_not_found import JudgeNotFound
from ory_oathkeeper_client.model.judge_not_found_body import JudgeNotFoundBody
from ory_oathkeeper_client.model.judge_unauthorized import JudgeUnauthorized
from ory_oathkeeper_client.model.judge_unauthorized_body import JudgeUnauthorizedBody
from ory_oathkeeper_client.model.list_rules_forbidden import ListRulesForbidden
from ory_oathkeeper_client.model.list_rules_forbidden_body import ListRulesForbiddenBody
from ory_oathkeeper_client.model.list_rules_internal_server_error import ListRulesInternalServerError
from ory_oathkeeper_client.model.list_rules_internal_server_error_body import ListRulesInternalServerErrorBody
from ory_oathkeeper_client.model.list_rules_ok import ListRulesOK
from ory_oathkeeper_client.model.list_rules_unauthorized import ListRulesUnauthorized
from ory_oathkeeper_client.model.list_rules_unauthorized_body import ListRulesUnauthorizedBody
from ory_oathkeeper_client.model.raw_message import RawMessage
from ory_oathkeeper_client.model.rule import Rule
from ory_oathkeeper_client.model.rule_handler import RuleHandler
from ory_oathkeeper_client.model.rule_match import RuleMatch
from ory_oathkeeper_client.model.swagger_create_rule_parameters import SwaggerCreateRuleParameters
from ory_oathkeeper_client.model.swagger_get_rule_parameters import SwaggerGetRuleParameters
from ory_oathkeeper_client.model.swagger_health_status import SwaggerHealthStatus
from ory_oathkeeper_client.model.swagger_json_web_key import SwaggerJSONWebKey
from ory_oathkeeper_client.model.swagger_json_web_key_set import SwaggerJSONWebKeySet
from ory_oathkeeper_client.model.swagger_list_rules_parameters import SwaggerListRulesParameters
from ory_oathkeeper_client.model.swagger_not_ready_status import SwaggerNotReadyStatus
from ory_oathkeeper_client.model.swagger_rule import SwaggerRule
from ory_oathkeeper_client.model.swagger_rule_handler import SwaggerRuleHandler
from ory_oathkeeper_client.model.swagger_rule_match import SwaggerRuleMatch
from ory_oathkeeper_client.model.swagger_rule_response import SwaggerRuleResponse
from ory_oathkeeper_client.model.swagger_rules_response import SwaggerRulesResponse
from ory_oathkeeper_client.model.swagger_update_rule_parameters import SwaggerUpdateRuleParameters
from ory_oathkeeper_client.model.swagger_version import SwaggerVersion
from ory_oathkeeper_client.model.update_rule_forbidden import UpdateRuleForbidden
from ory_oathkeeper_client.model.update_rule_forbidden_body import UpdateRuleForbiddenBody
from ory_oathkeeper_client.model.update_rule_internal_server_error import UpdateRuleInternalServerError
from ory_oathkeeper_client.model.update_rule_internal_server_error_body import UpdateRuleInternalServerErrorBody
from ory_oathkeeper_client.model.update_rule_not_found import UpdateRuleNotFound
from ory_oathkeeper_client.model.update_rule_not_found_body import UpdateRuleNotFoundBody
from ory_oathkeeper_client.model.update_rule_ok import UpdateRuleOK
from ory_oathkeeper_client.model.update_rule_unauthorized import UpdateRuleUnauthorized
from ory_oathkeeper_client.model.update_rule_unauthorized_body import UpdateRuleUnauthorizedBody
from ory_oathkeeper_client.model.upstream import Upstream
from ory_oathkeeper_client.model.version import Version



# coding: utf-8

"""
    ORY Oathkeeper

    ORY Oathkeeper is a reverse proxy that checks the HTTP Authorization for validity against a set of rules. This service uses Hydra to validate access tokens and policies.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.37
    Contact: hi@ory.am
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ory_oathkeeper_client.configuration import Configuration


class SwaggerRuleMatch(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'methods': 'list[str]',
        'url': 'str'
    }

    attribute_map = {
        'methods': 'methods',
        'url': 'url'
    }

    def __init__(self, methods=None, url=None, local_vars_configuration=None):  # noqa: E501
        """SwaggerRuleMatch - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._methods = None
        self._url = None
        self.discriminator = None

        if methods is not None:
            self.methods = methods
        if url is not None:
            self.url = url

    @property
    def methods(self):
        """Gets the methods of this SwaggerRuleMatch.  # noqa: E501

        An array of HTTP methods (e.g. GET, POST, PUT, DELETE, ...). When ORY Oathkeeper searches for rules to decide what to do with an incoming request to the proxy server, it compares the HTTP method of the incoming request with the HTTP methods of each rules. If a match is found, the rule is considered a partial match. If the matchesUrl field is satisfied as well, the rule is considered a full match.  # noqa: E501

        :return: The methods of this SwaggerRuleMatch.  # noqa: E501
        :rtype: list[str]
        """
        return self._methods

    @methods.setter
    def methods(self, methods):
        """Sets the methods of this SwaggerRuleMatch.

        An array of HTTP methods (e.g. GET, POST, PUT, DELETE, ...). When ORY Oathkeeper searches for rules to decide what to do with an incoming request to the proxy server, it compares the HTTP method of the incoming request with the HTTP methods of each rules. If a match is found, the rule is considered a partial match. If the matchesUrl field is satisfied as well, the rule is considered a full match.  # noqa: E501

        :param methods: The methods of this SwaggerRuleMatch.  # noqa: E501
        :type: list[str]
        """

        self._methods = methods

    @property
    def url(self):
        """Gets the url of this SwaggerRuleMatch.  # noqa: E501

        This field represents the URL pattern this rule matches. When ORY Oathkeeper searches for rules to decide what to do with an incoming request to the proxy server, it compares the full request URL (e.g. https://mydomain.com/api/resource) without query parameters of the incoming request with this field. If a match is found, the rule is considered a partial match. If the matchesMethods field is satisfied as well, the rule is considered a full match.  You can use regular expressions in this field to match more than one url. Regular expressions are encapsulated in brackets < and >. The following example matches all paths of the domain `mydomain.com`: `https://mydomain.com/<.*>`.  # noqa: E501

        :return: The url of this SwaggerRuleMatch.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this SwaggerRuleMatch.

        This field represents the URL pattern this rule matches. When ORY Oathkeeper searches for rules to decide what to do with an incoming request to the proxy server, it compares the full request URL (e.g. https://mydomain.com/api/resource) without query parameters of the incoming request with this field. If a match is found, the rule is considered a partial match. If the matchesMethods field is satisfied as well, the rule is considered a full match.  You can use regular expressions in this field to match more than one url. Regular expressions are encapsulated in brackets < and >. The following example matches all paths of the domain `mydomain.com`: `https://mydomain.com/<.*>`.  # noqa: E501

        :param url: The url of this SwaggerRuleMatch.  # noqa: E501
        :type: str
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SwaggerRuleMatch):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SwaggerRuleMatch):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ORY Oathkeeper

    ORY Oathkeeper is a reverse proxy that checks the HTTP Authorization for validity against a set of rules. This service uses Hydra to validate access tokens and policies.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.1
    Contact: hi@ory.am
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import ory_oathkeeper_client
from ory_oathkeeper_client.models.update_rule_not_found import UpdateRuleNotFound  # noqa: E501
from ory_oathkeeper_client.rest import ApiException


class TestUpdateRuleNotFound(unittest.TestCase):
    """UpdateRuleNotFound unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUpdateRuleNotFound(self):
        """Test UpdateRuleNotFound"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ory_oathkeeper_client.models.update_rule_not_found.UpdateRuleNotFound()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    ORY Oathkeeper

    ORY Oathkeeper is a reverse proxy that checks the HTTP Authorization for validity against a set of rules. This service uses Hydra to validate access tokens and policies.  # noqa: E501

    The version of the OpenAPI document: v0.0.0
    Contact: hi@ory.am
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import ory_oathkeeper_client
from ory_oathkeeper_client.model.raw_message import RawMessage


class TestRawMessage(unittest.TestCase):
    """RawMessage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRawMessage(self):
        """Test RawMessage"""
        # FIXME: construct object with mandatory attributes with example values
        # model = RawMessage()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ORY Oathkeeper

    ORY Oathkeeper is a reverse proxy that checks the HTTP Authorization for validity against a set of rules. This service uses Hydra to validate access tokens and policies.  # noqa: E501

    The version of the OpenAPI document: v0.38.5-beta.1
    Contact: hi@ory.am
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ory_oathkeeper_client.configuration import Configuration


class Rule(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'authenticators': 'list[RuleHandler]',
        'authorizer': 'RuleHandler',
        'description': 'str',
        'id': 'str',
        'match': 'RuleMatch',
        'mutators': 'list[RuleHandler]',
        'upstream': 'Upstream'
    }

    attribute_map = {
        'authenticators': 'authenticators',
        'authorizer': 'authorizer',
        'description': 'description',
        'id': 'id',
        'match': 'match',
        'mutators': 'mutators',
        'upstream': 'upstream'
    }

    def __init__(self, authenticators=None, authorizer=None, description=None, id=None, match=None, mutators=None, upstream=None, local_vars_configuration=None):  # noqa: E501
        """Rule - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._authenticators = None
        self._authorizer = None
        self._description = None
        self._id = None
        self._match = None
        self._mutators = None
        self._upstream = None
        self.discriminator = None

        if authenticators is not None:
            self.authenticators = authenticators
        if authorizer is not None:
            self.authorizer = authorizer
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        if match is not None:
            self.match = match
        if mutators is not None:
            self.mutators = mutators
        if upstream is not None:
            self.upstream = upstream

    @property
    def authenticators(self):
        """Gets the authenticators of this Rule.  # noqa: E501

        Authenticators is a list of authentication handlers that will try and authenticate the provided credentials. Authenticators are checked iteratively from index 0 to n and if the first authenticator to return a positive result will be the one used.  If you want the rule to first check a specific authenticator  before \"falling back\" to others, have that authenticator as the first item in the array.  # noqa: E501

        :return: The authenticators of this Rule.  # noqa: E501
        :rtype: list[RuleHandler]
        """
        return self._authenticators

    @authenticators.setter
    def authenticators(self, authenticators):
        """Sets the authenticators of this Rule.

        Authenticators is a list of authentication handlers that will try and authenticate the provided credentials. Authenticators are checked iteratively from index 0 to n and if the first authenticator to return a positive result will be the one used.  If you want the rule to first check a specific authenticator  before \"falling back\" to others, have that authenticator as the first item in the array.  # noqa: E501

        :param authenticators: The authenticators of this Rule.  # noqa: E501
        :type: list[RuleHandler]
        """

        self._authenticators = authenticators

    @property
    def authorizer(self):
        """Gets the authorizer of this Rule.  # noqa: E501


        :return: The authorizer of this Rule.  # noqa: E501
        :rtype: RuleHandler
        """
        return self._authorizer

    @authorizer.setter
    def authorizer(self, authorizer):
        """Sets the authorizer of this Rule.


        :param authorizer: The authorizer of this Rule.  # noqa: E501
        :type: RuleHandler
        """

        self._authorizer = authorizer

    @property
    def description(self):
        """Gets the description of this Rule.  # noqa: E501

        Description is a human readable description of this rule.  # noqa: E501

        :return: The description of this Rule.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Rule.

        Description is a human readable description of this rule.  # noqa: E501

        :param description: The description of this Rule.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this Rule.  # noqa: E501

        ID is the unique id of the rule. It can be at most 190 characters long, but the layout of the ID is up to you. You will need this ID later on to update or delete the rule.  # noqa: E501

        :return: The id of this Rule.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Rule.

        ID is the unique id of the rule. It can be at most 190 characters long, but the layout of the ID is up to you. You will need this ID later on to update or delete the rule.  # noqa: E501

        :param id: The id of this Rule.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def match(self):
        """Gets the match of this Rule.  # noqa: E501


        :return: The match of this Rule.  # noqa: E501
        :rtype: RuleMatch
        """
        return self._match

    @match.setter
    def match(self, match):
        """Sets the match of this Rule.


        :param match: The match of this Rule.  # noqa: E501
        :type: RuleMatch
        """

        self._match = match

    @property
    def mutators(self):
        """Gets the mutators of this Rule.  # noqa: E501

        Mutators is a list of mutation handlers that transform the HTTP request. A common use case is generating a new set of credentials (e.g. JWT) which then will be forwarded to the upstream server.  Mutations are performed iteratively from index 0 to n and should all succeed in order for the HTTP request to be forwarded.  # noqa: E501

        :return: The mutators of this Rule.  # noqa: E501
        :rtype: list[RuleHandler]
        """
        return self._mutators

    @mutators.setter
    def mutators(self, mutators):
        """Sets the mutators of this Rule.

        Mutators is a list of mutation handlers that transform the HTTP request. A common use case is generating a new set of credentials (e.g. JWT) which then will be forwarded to the upstream server.  Mutations are performed iteratively from index 0 to n and should all succeed in order for the HTTP request to be forwarded.  # noqa: E501

        :param mutators: The mutators of this Rule.  # noqa: E501
        :type: list[RuleHandler]
        """

        self._mutators = mutators

    @property
    def upstream(self):
        """Gets the upstream of this Rule.  # noqa: E501


        :return: The upstream of this Rule.  # noqa: E501
        :rtype: Upstream
        """
        return self._upstream

    @upstream.setter
    def upstream(self, upstream):
        """Sets the upstream of this Rule.


        :param upstream: The upstream of this Rule.  # noqa: E501
        :type: Upstream
        """

        self._upstream = upstream

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Rule):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Rule):
            return True

        return self.to_dict() != other.to_dict()
